@@ -1,5 +1,5 @@
 package Bot::Cobalt::Core::Loader;
-$Bot::Cobalt::Core::Loader::VERSION = '0.020001';
+$Bot::Cobalt::Core::Loader::VERSION = '0.021001';
 use strictures 2;
 use Carp;
 use Scalar::Util 'blessed';
@@ -52,7 +52,7 @@ sub load {
     undef
   } or confess $err;
 
-  $obj // ()
+  $obj
 }
 
 sub unload {
