@@ -1,5 +1,5 @@
 package Bot::Cobalt::Logger::Output;
-$Bot::Cobalt::Logger::Output::VERSION = '0.020001';
+$Bot::Cobalt::Logger::Output::VERSION = '0.021001';
 use Carp;
 use strictures 2;
 
@@ -34,7 +34,7 @@ sub add {
   
   unless (@args && @args % 2 == 0) {
     confess "add() expects an even number of arguments, ",
-         "mapping an Output class to constructor arguments"
+         "mapping an Output class to a HASH of constructor arguments"
   }
   
   my $prefix = 'Bot::Cobalt::Logger::Output::' ;
