@@ -1,5 +1,5 @@
 package Bot::Cobalt::Plugin::Alarmclock;
-$Bot::Cobalt::Plugin::Alarmclock::VERSION = '0.020001';
+$Bot::Cobalt::Plugin::Alarmclock::VERSION = '0.021001';
 use strictures 2;
 use v5.10;
 
@@ -99,6 +99,7 @@ sub Cobalt_register {
     public_cmd_alarmclock
     public_cmd_alarmdelete
     public_cmd_alarmdel
+    public_cmd_alarmclear
     executed_timer
   / );
 
@@ -133,6 +134,49 @@ sub Bot_executed_timer {
   PLUGIN_EAT_NONE
 }
 
+sub Bot_public_cmd_alarmclear {
+  my ($self, $core) = splice @_, 0, 2;
+  my $msg = ${ $_[0] };
+
+  my $context = $msg->context;
+  my $nick    = $msg->src_nick;
+
+  my $auth_usr = core->auth->username($context, $nick);
+  return PLUGIN_EAT_NONE unless $auth_usr
+    and core->auth->has_flag($context, $nick, 'SUPERUSER');
+
+  my $target_ctxt = $msg->message_array->[0];
+
+  logger->info(
+    "Clearing all alarms"
+    . ($target_ctxt ? " for context $target_ctxt" : "")
+    . " per $nick ($auth_usr)"
+  );
+
+  my $count = 0;
+  DELETE: for my $timerid (keys %{ $self->timers }) {
+    if ($target_ctxt) {
+      my $ctxt_set = $self->timers->{$timerid}->[0];
+      next DELETE unless $target_ctxt eq $ctxt_set;
+    }
+    core->timer_del($timerid);
+    delete $self->timers->{$timerid};
+    $self->_delete_alarm($timerid);
+    ++$count
+  }
+
+  broadcast( 'message', $context, $msg->channel,
+    core->rpl( q{ALARMCLOCK_DELETED},
+      nick    => $nick,
+      timerid => (
+        $target_ctxt ? "ALL [$target_ctxt] ($count)" : "ALL ($count)"
+      ),
+    )
+  );
+
+  PLUGIN_EAT_ALL
+}
+
 sub Bot_public_cmd_alarmdelete { Bot_public_cmd_alarmdel(@_) }
 
 sub Bot_public_cmd_alarmdel {
@@ -278,9 +322,17 @@ Bot::Cobalt::Plugin::Alarmclock - Timed IRC highlights
 
 =head1 SYNOPSIS
 
-  # On IRC:
-  !alarmclock 20m go do some something
-  !alarmclock 1h30m stop staring at irc
+  # Set alarms:
+  > !alarmclock 20m go do some something
+  > !alarmclock 1h30m stop staring at irc
+
+  # Remove alarms by timer ID:
+  > !alarmdel a1b2c
+
+  # Superusers can remove all alarms (version 0.21.1+):
+  > !alarmclear
+  # ... or all alarms for a specific context:
+  > !alarmclear Main
 
 =head1 DESCRIPTION
 
