@@ -1,10 +1,12 @@
 package Bot::Cobalt::Plugin::Extras::CPAN;
-$Bot::Cobalt::Plugin::Extras::CPAN::VERSION = '0.020001';
+$Bot::Cobalt::Plugin::Extras::CPAN::VERSION = '0.021001';
 use strictures 2;
 
 use Bot::Cobalt;
 use Bot::Cobalt::Common;
+
 use Bot::Cobalt::Serializer;
+our $Serializer = Bot::Cobalt::Serializer->new('JSON');
 
 use HTTP::Request;
 
@@ -12,31 +14,31 @@ use Module::CoreList;
 
 use Try::Tiny;
 
-## FIXME cachedb?
-sub CACHE () { 0 }
+our $HelpText
+  = 'try: dist, latest, tests, abstract, changes, belongs, license';
 
-sub new { bless [undef], shift }
+## FIXME cachedb?
+
+sub new { bless [], shift }
 
 sub Cobalt_register {
   my ($self, $core) = splice @_, 0, 2;
 
-  register( $self, 'SERVER',
-    'public_cmd_cpan',
-    'public_cmd_corelist',
-    'mcpan_plug_resp_recv',
-  );
+  register $self, SERVER => qw/
+    public_cmd_cpan
+    public_cmd_corelist
+    mcpan_plug_resp_recv
+  /;
 
   logger->info("Loaded: !cpan");
 
-  return PLUGIN_EAT_NONE
+  PLUGIN_EAT_NONE
 }
 
 sub Cobalt_unregister {
   my ($self, $core) = splice @_, 0, 2;
-
   logger->info("Bye!");
-
-  return PLUGIN_EAT_NONE
+  PLUGIN_EAT_NONE
 }
 
 sub Bot_public_cmd_corelist {
@@ -54,12 +56,8 @@ sub Bot_public_cmd_corelist {
   }
 
   my $resp;
-
   my $vers = $msg->message_array->[1];
-
-  my $first = Module::CoreList->first_release($dist, $vers);
-
-  if ($first) {
+  if (my $first = Module::CoreList->first_release($dist, $vers)) {
     $resp = $vers ?
             "$dist ($vers) was released with $first"
             : "$dist was released with $first"
@@ -82,29 +80,27 @@ sub Bot_public_cmd_cpan {
   unless ($cmd) {
     broadcast( 'message',
       $msg->context, $msg->channel,
-      "No command; try: dist, latest, tests, abstract, license",
+      "No command; $HelpText"
     );
     return PLUGIN_EAT_ALL
   }
 
   unless ($dist) {
-    ## assume 'abstract' if only one arg
+    # assume 'abstract' if only one arg
     $dist = $cmd;
     $cmd  = 'abstract';
   }
 
   $cmd = lc $cmd;
-
   $dist =~ s/::/-/g unless $cmd eq "belongs";
-
   my $url = "/release/$dist";
 
-  my $hints = {
+  my $hints = +{
     Context => $msg->context,
     Channel => $msg->channel,
     Nick    => $msg->src_nick,
     Dist    => $dist,
-    Link    => 'http://www.metacpan.org'.$url,
+    Link    => "http://www.metacpan.org${url}",
   };
 
   CMD: {
@@ -139,15 +135,20 @@ sub Bot_public_cmd_cpan {
       last CMD
     }
 
+    if ($cmd eq 'changes' || $cmd eq 'changelog') {
+      $hints->{Type} = 'changes';
+      $url = "/module/$dist";
+      last CMD
+    }
+
     broadcast( 'message', $msg->context, $msg->channel,
-      "Unknown query; try: dist, latest, tests, abstract, license, belongs"
+      "Unknown query; $HelpText"
     );
   }
 
-  $self->_request($url, $hints)
-    if defined $hints->{Type};
+  $self->_request($url, $hints) if defined $hints->{Type};
 
-  return PLUGIN_EAT_ALL
+  PLUGIN_EAT_ALL
 }
 
 sub _request {
@@ -158,9 +159,7 @@ sub _request {
 
   logger->debug("metacpan request: $this_url");
 
-  my $request = HTTP::Request->new(
-    'GET', $this_url
-  );
+  my $request = HTTP::Request->new(GET => $this_url);
 
   broadcast( 'www_request',
     $request,
@@ -180,7 +179,6 @@ sub Bot_mcpan_plug_resp_recv {
 
   unless ($response->is_success) {
     my $status = $response->code;
-
     if ($status == 404) {
       broadcast( 'message',
         $hints->{Context}, $hints->{Channel},
@@ -192,12 +190,10 @@ sub Bot_mcpan_plug_resp_recv {
         "Could not get release info for $dist ($status)"
       );
     }
-
     return PLUGIN_EAT_ALL
   }
 
   my $json = $response->content;
-
   unless ($json) {
     broadcast('message',
       $hints->{Context}, $hints->{Channel},
@@ -206,32 +202,26 @@ sub Bot_mcpan_plug_resp_recv {
     return PLUGIN_EAT_ALL
   }
 
-  my $ser = Bot::Cobalt::Serializer->new('JSON');
-
-  my $d_hash;
-  {
-    try {
-      $d_hash = $ser->thaw($json)
-    } catch {
+  my $d_hash = 
+    try { $Serializer->thaw($json) } 
+    catch {
       broadcast( 'message',
         $hints->{Context}, $hints->{Channel},
-        "Decoder failure; err: $_",
+        "thaw failure; err: $_",
       );
-      return PLUGIN_EAT_ALL
-    };
-  }
+      undef
+    } or return PLUGIN_EAT_ALL;
 
   unless ($d_hash && ref $d_hash eq 'HASH') {
     broadcast( 'message',
       $hints->{Context}, $hints->{Channel},
-      "Odd; no hash received after decode for $dist"
+      "thaw failure for $dist; expected a HASH but got '$d_hash'"
     );
     return PLUGIN_EAT_ALL
   }
 
   my $resp;
-
-  my $prefix = color('bold', 'mCPAN');
+  my $prefix = color bold => 'mCPAN';
 
   TYPE: {
 
@@ -285,6 +275,14 @@ sub Bot_mcpan_plug_resp_recv {
       last TYPE
     }
 
+    if ($type eq 'changes') {
+      my $release = $d_hash->{release};
+      my $actuald = substr $release, 0, rindex $release, '-';
+      my $link = "https://www.metacpan.org/changes/distribution/$actuald";
+      $resp = "$prefix: Changes for $release: $link";
+      last TYPE
+    }
+
     logger->error("BUG; fell through in response handler");
   }
 
@@ -293,7 +291,7 @@ sub Bot_mcpan_plug_resp_recv {
     $resp
   ) if $resp;
 
-  return PLUGIN_EAT_ALL
+  PLUGIN_EAT_ALL
 }
 
 1;
@@ -308,20 +306,26 @@ Bot::Cobalt::Plugin::Extras::CPAN - Query MetaCPAN API from IRC
 =head1 SYNOPSIS
 
   ## Retrieve dist abstract:
-  > !cpan Some::Dist
-  > !cpan abstract Some::Dist
+  > !cpan Moo
+  > !cpan abstract Bot::Cobalt
 
   ## Retrieve latest version:
-  > !cpan latest Some::Dist
+  > !cpan latest POE
 
   ## Test summary:
-  > !cpan tests Some::Dist
-
-  ## License info:
-  > !cpan license Some::Dist
+  > !cpan tests POE::Component::IRC
 
   ## Download link:
-  > !cpan dist Some::Dist
+  > !cpan dist App::bmkpasswd
+
+  ## Find out what distribution a module belongs to:
+  > !cpan belongs Lowu
+
+  ## Get ChangeLog link:
+  > !cpan changes Moo
+
+  ## License info:
+  > !cpan license Text::ZPL
 
   ## Query Module::CoreList:
   > !corelist Some::Dist
