@@ -1,5 +1,5 @@
 package Bot::Cobalt::Plugin::RDB;
-$Bot::Cobalt::Plugin::RDB::VERSION = '0.020001';
+$Bot::Cobalt::Plugin::RDB::VERSION = '0.021001';
 use v5.10;
 use strictures 2;
 
@@ -1363,6 +1363,12 @@ The RDB must already exist; see L</"rdb dbadd">
 
 =head2 rdb
 
+=head3 rdb get
+
+  rdb get <rdb> <itemID>
+
+Retrieves the specified item from the specified RDB.
+
 =head3 rdb info
 
   rdb info <rdb>
