@@ -1,19 +1,25 @@
 package Bot::Cobalt::Plugin::Seen;
-$Bot::Cobalt::Plugin::Seen::VERSION = '0.020001';
-use 5.10.1;
-
+$Bot::Cobalt::Plugin::Seen::VERSION = '0.021001';
+use v5.10;
 use Bot::Cobalt;
 use Bot::Cobalt::Common;
 use Bot::Cobalt::DB;
 
 use Path::Tiny;
 
-sub new { bless +{}, shift }
+sub SDB () { 0 }
+sub BUF () { 1 }
 
-sub parse_nick {
-  my ($self, $context, $nickname) = @_;
-  my $casemap = core->get_irc_casemap($context) || 'rfc1459';
-  lc_irc($nickname, $casemap)
+sub new { 
+  bless [
+    undef, # SDB
+    +{},   # BUF
+  ], shift
+}
+
+sub _parse_nick {
+  my ($context, $nickname) = @_;
+  lc_irc $nickname, (core->get_irc_casemap($context) || 'rfc1459')
 }
 
 ## FIXME method to retrieve users w/ similar hosts
@@ -21,18 +27,15 @@ sub parse_nick {
 
 sub retrieve {
   my ($self, $context, $nickname) = @_;
-  $nickname = $self->parse_nick($context, $nickname);
+  $nickname = _parse_nick($context, $nickname);
 
-  my $thisbuf = $self->{Buf}->{$context} // {};
-
-  my $ref = $thisbuf->{$nickname};
+  my $ref = $self->[BUF]->{$context}->{$nickname}; # intentional autoviv
   unless (defined $ref) {
-    my $db = $self->{SDB};
+    my $db = $self->[SDB];
     unless ($db->dbopen) {
       logger->warn("dbopen failed in retrieve; cannot open SeenDB");
       return
     }
-
     my $thiskey = $context .'%'. $nickname;
     $ref = $db->get($thiskey);
     $db->dbclose;
@@ -51,12 +54,11 @@ sub Cobalt_register {
   
   logger->info("Opening SeenDB at $seendb_path");
 
-  $self->{Buf} = +{};
+  $self->[BUF] = +{};
+  $self->[SDB] = Bot::Cobalt::DB->new(file => $seendb_path);
   
-  $self->{SDB} = Bot::Cobalt::DB->new(file => $seendb_path);
-  
-  my $rc = $self->{SDB}->dbopen;
-  $self->{SDB}->dbclose;
+  my $rc = $self->[SDB]->dbopen;
+  $self->[SDB]->dbclose;
   unless ($rc) {
     logger->warn("Failed to open SeenDB at $seendb_path");
     die "Unable to open SeenDB at $seendb_path"
@@ -87,27 +89,27 @@ sub Cobalt_register {
   
   logger->info("Loaded");
   
-  return PLUGIN_EAT_NONE
+  PLUGIN_EAT_NONE
 }
 
 sub Cobalt_unregister {
   my ($self, $core) = splice @_, 0, 2;
   $self->Bot_seendb_update($core, \1);
   $core->log->info("Unloaded");
-  return PLUGIN_EAT_NONE
+  PLUGIN_EAT_NONE
 }
 
 sub Bot_seendb_update {
   my ($self, $core) = splice @_, 0, 2;
   my $force_flush = @_ ? ${ $_[0] } : 0;
 
-  my $buf = $self->{Buf};
+  my $buf = $self->[BUF];
   unless (keys %$buf) {
     $core->timer_set( 2, +{ Event => 'seendb_update' } );
     return PLUGIN_EAT_ALL
   }
 
-  my $db  = $self->{SDB};
+  my $db  = $self->[SDB];
 
   CONTEXT: for my $context (keys %$buf) {
     unless ($db->dbopen) {
@@ -122,7 +124,7 @@ sub Bot_seendb_update {
       ## if we've done a lot of writes, yield back (unless we're cleaning up)
       if (!$force_flush && $writes && $writes % 50 == 0) {
         $db->dbclose;
-        broadcast( 'seendb_update' );
+        broadcast 'seendb_update';
         return PLUGIN_EAT_ALL
       }
       ## .. else flush this item to disk
@@ -152,8 +154,8 @@ sub Bot_user_joined {
   my $host = $join->src_host;
   my $chan = $join->channel;
 
-  $nick = $self->parse_nick($context, $nick);
-  $self->{Buf}->{$context}->{$nick} = +{
+  $nick = _parse_nick($context, $nick);
+  $self->[BUF]->{$context}->{$nick} = +{
     TS       => time(),
     Action   => 'join',
     Channel  => $chan,
@@ -161,7 +163,7 @@ sub Bot_user_joined {
     Host     => $host,
   };
   
-  return PLUGIN_EAT_NONE
+  PLUGIN_EAT_NONE
 }
 
 sub Bot_chan_sync {
@@ -169,9 +171,9 @@ sub Bot_chan_sync {
   my $context = ${$_[0]};
   my $channel = ${$_[1]};
 
-  broadcast( 'seenplug_deferred_list', $context, $channel );
+  broadcast seenplug_deferred_list => $context, $channel;
 
-  return PLUGIN_EAT_NONE
+  PLUGIN_EAT_NONE
 }
 
 sub Bot_seenplug_deferred_list {
@@ -182,8 +184,8 @@ sub Bot_seenplug_deferred_list {
   my $irc   = $core->get_irc_object($context);
   my @nicks = $irc->channel_list($channel);
   for my $nick (@nicks) {
-    $nick = $self->parse_nick($context, $nick);
-    $self->{Buf}->{$context}->{$nick} = {
+    $nick = _parse_nick($context, $nick);
+    $self->[BUF]->{$context}->{$nick} = +{
       TS       => time(),
       Action   => 'present',
       Channel  => $channel,
@@ -192,7 +194,7 @@ sub Bot_seenplug_deferred_list {
     };
   }
   
-  return PLUGIN_EAT_ALL
+  PLUGIN_EAT_ALL
 }
 
 sub Bot_user_left {
@@ -205,8 +207,8 @@ sub Bot_user_left {
   my $host = $part->src_host;
   my $chan = $part->channel;
 
-  $nick = $self->parse_nick($context, $nick);
-  $self->{Buf}->{$context}->{$nick} = {
+  $nick = _parse_nick($context, $nick);
+  $self->[BUF]->{$context}->{$nick} = +{
     TS => time(),
     Action   => 'part',
     Channel  => $chan,
@@ -214,7 +216,7 @@ sub Bot_user_left {
     Host     => $host,
   };
 
-  return PLUGIN_EAT_NONE
+  PLUGIN_EAT_NONE
 }
 
 sub Bot_user_quit {
@@ -227,8 +229,8 @@ sub Bot_user_quit {
   my $host = $quit->src_host;
   my $common = $quit->common;
 
-  $nick = $self->parse_nick($context, $nick);
-  $self->{Buf}->{$context}->{$nick} = {
+  $nick = _parse_nick($context, $nick);
+  $self->[BUF]->{$context}->{$nick} = +{
     TS => time(),
     Action   => 'quit',
     Channel  => $common->[0],
@@ -236,7 +238,7 @@ sub Bot_user_quit {
     Host     => $host,
   };
   
-  return PLUGIN_EAT_NONE
+  PLUGIN_EAT_NONE
 }
 
 sub Bot_nick_changed {
@@ -254,7 +256,7 @@ sub Bot_nick_changed {
   
   my $first_common = $nchange->channels->[0];
 
-  $self->{Buf}->{$context}->{$old} = {
+  $self->[BUF]->{$context}->{$old} = +{
     TS => time(),
     Action   => 'nchange',
     Channel  => $first_common,
@@ -263,7 +265,7 @@ sub Bot_nick_changed {
     Meta     => { To => $new },
   };
   
-  $self->{Buf}->{$context}->{$new} = {
+  $self->[BUF]->{$context}->{$new} = +{
     TS => time(),
     Action   => 'nchange',
     Channel  => $first_common,
@@ -272,7 +274,7 @@ sub Bot_nick_changed {
     Meta     => { From => $old },
   };
   
-  return PLUGIN_EAT_NONE
+  PLUGIN_EAT_NONE
 }
 
 sub Bot_public_cmd_seen {
@@ -286,22 +288,16 @@ sub Bot_public_cmd_seen {
   my $targetnick = $msg->message_array->[0];
   
   unless ($targetnick) {
-    broadcast( 'message', 
-      $context,
-      $channel,
-      "Need a nickname to look for, $nick"
-    );
+    broadcast message => $context, $channel,
+      "Need a nickname to look for, $nick";
     return PLUGIN_EAT_NONE
   }
   
   my $ref = $self->retrieve($context, $targetnick);
   
   unless ($ref) {
-    broadcast( 'message',
-      $context,
-      $channel,
-      "${nick}: I don't know anything about $targetnick"
-    );
+    broadcast message => $context, $channel,
+      "${nick}: I don't know anything about $targetnick";
 
     return PLUGIN_EAT_NONE
   }
@@ -364,13 +360,9 @@ sub Bot_public_cmd_seen {
     $resp = 'Something weird happened; check log file for details.';
   }  
 
-  broadcast( 'message', 
-    $context,
-    $channel,
-    $resp
-  );  
+  broadcast message => $context, $channel, $resp;  
   
-  return PLUGIN_EAT_NONE
+  PLUGIN_EAT_NONE
 }
 
 1;
