@@ -1,5 +1,5 @@
 package Bot::Cobalt::Utils;
-$Bot::Cobalt::Utils::VERSION = '0.020001';
+$Bot::Cobalt::Utils::VERSION = '0.021001';
 use strictures 2;
 use Carp;
 use Scalar::Util 'reftype';
@@ -160,11 +160,9 @@ sub glob_to_re_str ($) {
       }
       $first = 0;
     ## So is trailing $ (end):
-    } elsif ($last) {
-      if ($ch eq '$') {
-        $re .= '$' ;
-        last
-      }
+    } elsif ($last && $ch eq '$') {
+      $re .= '$' ;
+      last
     }
 
     ## Escape metas:
